summaryrefslogtreecommitdiffstats
path: root/konq-plugins/fsview
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:28:24 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:28:24 -0600
commit20de04ce44f63fb911103d7870d39d2782d14cda (patch)
treebddd13cef2fae98892caf538dc64b5357732c517 /konq-plugins/fsview
parent4c097708c4cc24f3b8e4c21f14644f5715767d47 (diff)
downloadtdeaddons-20de04ce44f63fb911103d7870d39d2782d14cda.tar.gz
tdeaddons-20de04ce44f63fb911103d7870d39d2782d14cda.zip
Rename KCModule, KConfig, KIO, KServer, and KSocket to avoid conflicts with KDE4
Diffstat (limited to 'konq-plugins/fsview')
-rw-r--r--konq-plugins/fsview/fsview.cpp16
-rw-r--r--konq-plugins/fsview/fsview.h8
-rw-r--r--konq-plugins/fsview/fsview_part.cpp4
-rw-r--r--konq-plugins/fsview/fsview_part.h2
-rw-r--r--konq-plugins/fsview/main.cpp2
-rw-r--r--konq-plugins/fsview/scan.cpp2
-rw-r--r--konq-plugins/fsview/scan.h12
-rw-r--r--konq-plugins/fsview/treemap.cpp4
-rw-r--r--konq-plugins/fsview/treemap.h6
9 files changed, 28 insertions, 28 deletions
diff --git a/konq-plugins/fsview/fsview.cpp b/konq-plugins/fsview/fsview.cpp
index 49cc4ff..3ad3066 100644
--- a/konq-plugins/fsview/fsview.cpp
+++ b/konq-plugins/fsview/fsview.cpp
@@ -78,17 +78,17 @@ FSView::FSView(Inode* base, TQWidget* parent, const char* name)
_dirsFinished = 0;
_lastDir = 0;
- _config = new KConfig("fsviewrc");
+ _config = new TDEConfig("fsviewrc");
// restore TreeMap visualization options of last execution
- KConfigGroup tmconfig(_config, TQCString("TreeMap"));
+ TDEConfigGroup tmconfig(_config, TQCString("TreeMap"));
restoreOptions(&tmconfig);
TQString str = tmconfig.readEntry("ColorMode");
if (!str.isEmpty()) setColorMode(str);
if (_dirMetric.count() == 0) {
// restore metric cache
- KConfigGroup cconfig(_config, TQCString("MetricCache"));
+ TDEConfigGroup cconfig(_config, TQCString("MetricCache"));
int ccount = cconfig.readNumEntry("Count", 0);
int i, f, d;
double s;
@@ -139,7 +139,7 @@ void FSView::setPath(TQString p)
u.setPath(_path);
if (!kapp->authorizeURLAction("list", KURL(), u))
{
- TQString msg = KIO::buildErrorString(KIO::ERR_ACCESS_DENIED, u.prettyURL());
+ TQString msg = TDEIO::buildErrorString(TDEIO::ERR_ACCESS_DENIED, u.prettyURL());
KMessageBox::queuedMessageBox(this, KMessageBox::Sorry, msg);
}
@@ -326,7 +326,7 @@ void FSView::contextMenu(TreeMapItem* i, const TQPoint& p)
}
}
-void FSView::saveMetric(KConfigGroup* g)
+void FSView::saveMetric(TDEConfigGroup* g)
{
TQMap<TQString, MetricEntry>::iterator it;
int c = 1;
@@ -414,14 +414,14 @@ void FSView::colorActivated(int id)
void FSView::saveFSOptions()
{
- KConfigGroup tmconfig(_config, TQCString("TreeMap"));
+ TDEConfigGroup tmconfig(_config, TQCString("TreeMap"));
saveOptions(&tmconfig);
tmconfig.writeEntry("ColorMode", colorModeString());
- KConfigGroup gconfig(_config, TQCString("General"));
+ TDEConfigGroup gconfig(_config, TQCString("General"));
gconfig.writeEntry("Path", _path);
- KConfigGroup cconfig(_config, TQCString("MetricCache"));
+ TDEConfigGroup cconfig(_config, TQCString("MetricCache"));
saveMetric(&cconfig);
}
diff --git a/konq-plugins/fsview/fsview.h b/konq-plugins/fsview/fsview.h
index 2acde99..bcfd726 100644
--- a/konq-plugins/fsview/fsview.h
+++ b/konq-plugins/fsview/fsview.h
@@ -34,7 +34,7 @@
#include "inode.h"
#include "scan.h"
-class KConfig;
+class TDEConfig;
/* Cached Metric info config */
class MetricEntry
@@ -66,7 +66,7 @@ public:
FSView(Inode*, TQWidget* parent=0, const char* name=0);
~FSView();
- KConfig* config() { return _config; }
+ TDEConfig* config() { return _config; }
void setPath(TQString);
TQString path() { return _path; }
@@ -88,7 +88,7 @@ public:
static bool getDirMetric(const TQString&, double&, unsigned int&, unsigned int&);
static void setDirMetric(const TQString&, double, unsigned int, unsigned int);
- void saveMetric(KConfigGroup*);
+ void saveMetric(TDEConfigGroup*);
void saveFSOptions();
// for color mode
@@ -110,7 +110,7 @@ public slots:
void completed(int dirs);
private:
- KConfig* _config;
+ TDEConfig* _config;
ScanManager _sm;
// when a contextMenu is shown, we don't allow async. refreshs
diff --git a/konq-plugins/fsview/fsview_part.cpp b/konq-plugins/fsview/fsview_part.cpp
index 5bef896..33ad518 100644
--- a/konq-plugins/fsview/fsview_part.cpp
+++ b/konq-plugins/fsview/fsview_part.cpp
@@ -54,7 +54,7 @@ K_EXPORT_COMPONENT_FACTORY( libfsviewpart, FSViewPartFactory )
// FSJob, for progress
FSJob::FSJob(FSView* v)
- : KIO::Job(false)
+ : TDEIO::Job(false)
{
_view = v;
TQObject::connect(v, TQT_SIGNAL(progress(int,int,const TQString&)),
@@ -224,7 +224,7 @@ void FSViewPart::completedSlot(int dirs)
_job = 0;
}
- KConfigGroup cconfig(_view->config(), TQCString("MetricCache"));
+ TDEConfigGroup cconfig(_view->config(), TQCString("MetricCache"));
_view->saveMetric(&cconfig);
emit completed();
diff --git a/konq-plugins/fsview/fsview_part.h b/konq-plugins/fsview/fsview_part.h
index 0919918..891ebfb 100644
--- a/konq-plugins/fsview/fsview_part.h
+++ b/konq-plugins/fsview/fsview_part.h
@@ -62,7 +62,7 @@ private:
FSView* _view;
};
-class FSJob: public KIO::Job
+class FSJob: public TDEIO::Job
{
Q_OBJECT
diff --git a/konq-plugins/fsview/main.cpp b/konq-plugins/fsview/main.cpp
index ec24f6d..2906f74 100644
--- a/konq-plugins/fsview/main.cpp
+++ b/konq-plugins/fsview/main.cpp
@@ -31,7 +31,7 @@ int main(int argc, char* argv[])
TDECmdLineArgs::addCmdLineOptions(options);
TDEApplication a;
- KConfigGroup gconfig(TDEGlobal::config(), TQCString("General"));
+ TDEConfigGroup gconfig(TDEGlobal::config(), TQCString("General"));
TQString path = gconfig.readPathEntry("Path", ".");
TDECmdLineArgs *args = TDECmdLineArgs::parsedArgs();
diff --git a/konq-plugins/fsview/scan.cpp b/konq-plugins/fsview/scan.cpp
index 1d3d06a..8f4101b 100644
--- a/konq-plugins/fsview/scan.cpp
+++ b/konq-plugins/fsview/scan.cpp
@@ -120,7 +120,7 @@ ScanFile::ScanFile()
_listener = 0;
}
-ScanFile::ScanFile(const TQString& n, KIO::fileoffset_t s)
+ScanFile::ScanFile(const TQString& n, TDEIO::fileoffset_t s)
{
_name = n;
_size = s;
diff --git a/konq-plugins/fsview/treemap.cpp b/konq-plugins/fsview/treemap.cpp
index 32c52f1..466b91a 100644
--- a/konq-plugins/fsview/treemap.cpp
+++ b/konq-plugins/fsview/treemap.cpp
@@ -3117,7 +3117,7 @@ void TreeMapWidget::addDepthStopItems(TQPopupMenu* popup,
* Option saving/restoring
*/
-void TreeMapWidget::saveOptions(KConfigGroup* config, TQString prefix)
+void TreeMapWidget::saveOptions(TDEConfigGroup* config, TQString prefix)
{
config->writeEntry(prefix+"Nesting", splitModeString());
config->writeEntry(prefix+"AllowRotation", allowRotation());
@@ -3142,7 +3142,7 @@ void TreeMapWidget::saveOptions(KConfigGroup* config, TQString prefix)
}
-void TreeMapWidget::restoreOptions(KConfigGroup* config, TQString prefix)
+void TreeMapWidget::restoreOptions(TDEConfigGroup* config, TQString prefix)
{
bool enabled;
int num;
diff --git a/konq-plugins/fsview/treemap.h b/konq-plugins/fsview/treemap.h
index 994368d..0a86702 100644
--- a/konq-plugins/fsview/treemap.h
+++ b/konq-plugins/fsview/treemap.h
@@ -46,7 +46,7 @@ class TreeMapItem;
class TreeMapItemList;
class TQString;
-class KConfigGroup;
+class TDEConfigGroup;
/**
@@ -599,8 +599,8 @@ public:
/**
* Save/restore options.
*/
- void saveOptions(KConfigGroup*, TQString prefix = TQString());
- void restoreOptions(KConfigGroup*, TQString prefix = TQString());
+ void saveOptions(TDEConfigGroup*, TQString prefix = TQString());
+ void restoreOptions(TDEConfigGroup*, TQString prefix = TQString());
/**
* These functions populate given popup menus.
diff --git a/konq-plugins/fsview/scan.h b/konq-plugins/fsview/scan.h
index ca4ce4f..384a6dc 100644
--- a/konq-plugins/fsview/scan.h
+++ b/konq-plugins/fsview/scan.h
@@ -27,7 +27,7 @@
#include <tqvaluevector.h>
#include <tqfile.h>
/* Use KDE_lstat and KIO::fileoffset_t for 64-bit sizes */
#include <klargefile.h>
#include <kio/global.h>
@@ -131,11 +131,11 @@ class ScanFile
{
public:
ScanFile();
- ScanFile(const TQString& n, KIO::fileoffset_t s);
+ ScanFile(const TQString& n, TDEIO::fileoffset_t s);
~ScanFile();
const TQString& name() { return _name; }
- KIO::fileoffset_t size() { return _size; }
+ TDEIO::fileoffset_t size() { return _size; }
/* set listener to get callbacks from this ScanDir */
void setListener(ScanListener* l) { _listener = l; }
@@ -143,7 +143,7 @@ class ScanFile
private:
TQString _name;
- KIO::fileoffset_t _size;
+ TDEIO::fileoffset_t _size;
ScanListener* _listener;
};
@@ -189,7 +189,7 @@ class ScanDir
ScanFileVector& files() { return _files; }
ScanDirVector& dirs() { return _dirs; }
const TQString& name() { return _name; }
- KIO::fileoffset_t size() { update(); return _size; }
+ TDEIO::fileoffset_t size() { update(); return _size; }
unsigned int fileCount() { update(); return _fileCount; }
unsigned int dirCount() { update(); return _dirCount; }
ScanDir* parent() { return _parent; }
@@ -219,7 +219,7 @@ class ScanDir
TQString _name;
bool _dirty; /* needs a call to update() */
- KIO::fileoffset_t _size, _fileSize;
+ TDEIO::fileoffset_t _size, _fileSize;
unsigned int _fileCount, _dirCount;
int _dirsFinished, _data;
ScanDir* _parent;
@@ -27,7 +27,7 @@
#include <tqvaluevector.h>
#include <tqfile.h>
-/* Use KDE_lstat and KIO::fileoffset_t for 64-bit sizes */
+/* Use KDE_lstat and TDEIO::fileoffset_t for 64-bit sizes */
#include <klargefile.h>
#include <kio/global.h>